@@ -1,3 +1,6 @@
+#ifndef _WIN32
+#include "config.h"
+#endif
 
 #include "../Common/Common.h"
 
@@ -5,8 +8,9 @@
 
 #include <cmath>
 #include <cfloat>
-#include <math.h>
+#include <iostream>
 
+#ifndef WITH_DARWIN
 double round(double dVal) {
   double dF = floor(dVal);
   double dC = ceil(dVal);
@@ -16,10 +20,10 @@ double round(double dVal) {
   else
     return dC;
 }
+#endif
 
 CAutoSpeedControl::CAutoSpeedControl(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, double dFrameRate) 
   : CDasherComponent(pEventHandler, pSettingsStore) {
-
   //scale #samples by #samples = m_dSamplesScale / (current bitrate) + m_dSampleOffset
   m_dSampleScale = 1.5;
   m_dSampleOffset = 1.3;
@@ -132,6 +136,7 @@ inline int CAutoSpeedControl::UpdateSampleSize(double dFrameRate)
   dSpeedSamples = dFramerate * (m_dSampleScale / dBitrate + m_dSampleOffset);
  
   m_nSpeedSamples = int(round(dSpeedSamples));
+
   return m_nSpeedSamples;
 }
   /////////////////////////////////////////////////////////////
@@ -187,6 +192,7 @@ void CAutoSpeedControl::SpeedControl(myint iDasherX, myint iDasherY, double dFra
     double y = -(iDasherY - iDasherOY) / double(iDasherOY); 
     double theta = atan2(y, x);
     double r = sqrt(x * x + y * y);
+
     m_dBitrate = GetLongParameter(LP_MAX_BITRATE) / 100.0; //  stored as long(round(true bitrate * 100))
 
     UpdateSigmas(r, dFrameRate);
