@@ -14,13 +14,23 @@
 #include <iostream>
 #include <pthread.h>
 
+#define GCC_VERSION (__GNUC__ * 10000 \
+                     + __GNUC_MINOR__ * 100 \
+                     + __GNUC_PATCHLEVEL__)
+
+
+
 namespace Dasher {
   class CSocketInput;
+#if GCC_VERSION >= 40100
+  void *ThreadLauncherStub(void *_myClass);
+#endif
 }
 
 using namespace Dasher;
 using namespace std;
-
+/// \ingroup Input
+/// \{
 class Dasher::CSocketInput:public CSocketInputBase {
 
   // This non-member launcher stub function is required because pthreads can't launch a non-static member method.
@@ -51,5 +61,5 @@ private:
   // TODO: should probably override ReportErrnoError() to popup a Gtk error message
 
 };
-
+/// \}
 #endif
