@@ -1,6 +1,7 @@
 
 #include "../Common/Common.h"
 
+#include <cstring>
 #include "TimeSpan.h"
 
 #ifdef _WIN32
@@ -122,7 +123,7 @@ string CTimeSpan::GetTimeStamp()
     szTimeLine = ctime(&(sTimeBuffer.time));
 #else
     gettimeofday(&sTimeBuffer, &sTimezoneBuffer);
-    szTimeLine = ctime(&(sTimeBuffer.tv_sec));
+    szTimeLine = ctime((const time_t *)&(sTimeBuffer.tv_sec));
 #endif
   
   if ((szTimeLine != NULL) && (strlen(szTimeLine) > 18))
@@ -134,7 +135,7 @@ string CTimeSpan::GetTimeStamp()
 #ifdef _WIN32
     sprintf(szMs, "%d", sTimeBuffer.millitm);
 #else
-    sprintf(szMs, "%d", sTimeBuffer.tv_usec / 1000);
+    sprintf(szMs, "%d", static_cast<int>(sTimeBuffer.tv_usec / 1000));
 #endif
     if (strlen(szMs) == 1)
       strTimeStamp += "00";
@@ -196,7 +197,7 @@ string CTimeSpan::GetDateStamp()
     szTimeLine = ctime(&(sTimeBuffer.time));
 #else
     gettimeofday(&sTimeBuffer, &sTimezoneBuffer);
-    szTimeLine = ctime(&(sTimeBuffer.tv_sec));
+    szTimeLine = ctime((const time_t *)&(sTimeBuffer.tv_sec));
 #endif
 
  
