@@ -1,6 +1,7 @@
 #include "../Common/Common.h"
 #include "../../config.h"
 
+#include <cstring>
 #include <iostream>
 #include "DasherControl.h"
 #include "Timer.h"
@@ -13,6 +14,7 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
 #include <sys/stat.h>
+#include <unistd.h>
 using namespace std;
 
 // 'Private' methods (only used in this file)
@@ -122,6 +124,7 @@ void CDasherControl::SetupPaths() {
 
   SetStringParameter(SP_SYSTEM_LOC, system_data_dir);
   SetStringParameter(SP_USER_LOC, user_data_dir);
+  delete[] user_data_dir;
 }
 
 void CDasherControl::CreateSettingsStore() {
@@ -228,6 +231,10 @@ void CDasherControl::SetFocus() {
   gtk_widget_grab_focus(m_pCanvas);
 }
 
+void CDasherControl::GameMessageOut(int message, const void* messagedata) {
+  gtk_dasher_control_game_messageout(m_pDasherControl, message, messagedata);
+}
+
 GArray *CDasherControl::GetAllowedValues(int iParameter) {
   // Glib version of the STL based core function
 
@@ -255,10 +262,10 @@ void CDasherControl::RealizeCanvas(GtkWidget *pWidget) {
 
 void CDasherControl::StartTimer() {
   // Start the timer loops as everything is set up
-  // Aim for 20 frames per second
+  // Aim for 40 frames per second, computers are getting faster
 
   if(g_iTimeoutID == 0) {
-    g_iTimeoutID = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 50, timer_callback, this, NULL);
+    g_iTimeoutID = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 25, timer_callback, this, NULL);
     // TODO: Reimplement this (or at least reimplement some kind of status reporting)
     //g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 5000, long_timer_callback, this, NULL);
   }
