@@ -10,7 +10,9 @@
 #ifdef WITH_MAEMOFULLSCREEN
 #include <hildon-widgets/hildon-program.h>
 #endif
+#ifdef GNOME_LIBS
 #include <libgnome/libgnome.h>
+#endif
 #include <unistd.h>
 
 #include "GtkDasherControl.h"
@@ -35,6 +37,7 @@ static gboolean g_bSend = true;
 
 struct _DasherMainPrivate {
   GladeXML *pGladeXML;
+  GladeXML *pPrefXML;
 
   // Child objects owned here
   DasherAppSettings *pAppSettings;
@@ -134,7 +137,7 @@ static void dasher_main_setup_window_state(DasherMain *pSelf);
 static void dasher_main_setup_window_style(DasherMain *pSelf);
 static void dasher_main_setup_internal_layout(DasherMain *pSelf);
 //static void dasher_main_refresh_font(DasherMain *pSelf);
-static void dasher_main_set_filename(DasherMain *pSelf);
+static void dasher_main_set_window_title(DasherMain *pSelf);
 
 /* ... Table based menu/toolbar commands */
 static void dasher_main_connect_menus(DasherMain *pSelf);
@@ -154,6 +157,7 @@ static void dasher_main_alphabet_combo_changed(DasherMain *pSelf);
 static void dasher_main_populate_alphabet_combo(DasherMain *pSelf);
 
 /* TODO: order these in file */
+static GladeXML *dasher_main_open_glade_xml(const char *szGladeFilename);
 static void dasher_main_load_interface(DasherMain *pSelf);
 static void dasher_main_create_preferences(DasherMain *pSelf);
 static void dasher_main_handle_parameter_change(DasherMain *pSelf, int iParameter);
@@ -280,12 +284,13 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
 	dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, APP_STYLE_FULLSCREEN);
       }
       else {
-	g_error("Application style %s is not supported", pCommandLine->szAppStyle);
+        g_critical("Application style %s is not supported", pCommandLine->szAppStyle);
+        return 0;
       }
     }
     else { 
       // By default use traditional mode
-      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, 0);
+      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_STYLE, APP_STYLE_TRAD);
     }
 
     dasher_main_load_interface(pDasherMain);
@@ -302,6 +307,8 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
 
       while(*pszCurrent) {
 	gchar *szJoin = g_strrstr(*pszCurrent, "=");
+        // Note to translators: This message will be output for command line errors when the "=" in --options=foo is missing.
+        const gchar *errorMessage = _("option setting is missing \"=\".");
 
 	if(szJoin) {
 	  int iLength = szJoin - *pszCurrent;
@@ -310,12 +317,15 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
 	  memcpy(szKey, *pszCurrent, iLength);
 	  szKey[iLength] = '\0';
 	  
-	  dasher_app_settings_cl_set(pPrivate->pAppSettings, szKey, szJoin + 1);
+	  errorMessage = dasher_app_settings_cl_set(pPrivate->pAppSettings, szKey, szJoin + 1);
 	  
 	  g_free(szKey);
 	}
-	else {
-	  g_error("Invalid option string specified");
+        
+	if (errorMessage) {
+          // Note to translators: This string will be output when --options= specifies an unknown option.
+	  g_critical("%s: '%s', %s", _("Invalid option string specified"), *pszCurrent, errorMessage);
+          return 0;
 	}
 
 	++pszCurrent;
@@ -375,8 +385,11 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
     g_object_unref(pPrivate->pGladeXML);
     pPrivate->pGladeXML = 0;
 
+    g_object_unref(pPrivate->pPrefXML);
+    pPrivate->pPrefXML = 0;
+
     /* Set up various bits and pieces */
-    dasher_main_set_filename(pDasherMain);
+    dasher_main_set_window_title(pDasherMain);
     dasher_main_populate_controls(pDasherMain);
     dasher_main_connect_control(pDasherMain);
 
@@ -386,12 +399,28 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
   }
 }
 
+static GladeXML *
+dasher_main_open_glade_xml(const char *szGladeFilename) {
+  g_message("Opening Glade file: %s", szGladeFilename);
+
+  GladeXML *xml = glade_xml_new(szGladeFilename, NULL, NULL);
+
+  if (!xml) {
+    g_error("Can't find Glade file: %s. Dasher is unlikely to be correctly installed.", szGladeFilename);
+  }
+
+  glade_xml_signal_autoconnect(xml);
+  
+  return xml;
+}
+
 /* Load the window interface from the glade file, and do various initialisation bits and pieces */
 static void 
 dasher_main_load_interface(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
   
   const char *szGladeFilename = NULL;
+  const char *szPrefGladeFilename = NULL;
 
 #ifdef WITH_GPE
   szGladeFilename = PROGDATA "/dashergpe.glade";
@@ -403,6 +432,7 @@ dasher_main_load_interface(DasherMain *pSelf) {
   //szGladeFilename = "/var/lib/install" PROGDATA "/dashermaemo.glade";
   szGladeFilename = PROGDATA "/dashermaemo.glade";
 #endif
+  szPrefGladeFilename = PROGDATA "/dashermaemo.preferences.glade";
 #else
   switch(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE)) {
   case APP_STYLE_TRAD:
@@ -420,21 +450,22 @@ dasher_main_load_interface(DasherMain *pSelf) {
   default:
     g_error("Inconsistent application style specified.");
   }
+  szPrefGladeFilename = PROGDATA "/dasher.preferences.glade";
 #endif
 
   if(!szGladeFilename) {
     g_error("Failure to determine glade filename");
   }
 
-  g_message("Glade file is: %s", szGladeFilename);
+  pPrivate->pGladeXML = dasher_main_open_glade_xml(szGladeFilename);
 
-  pPrivate->pGladeXML = glade_xml_new(szGladeFilename, NULL, NULL);
-
-  if (!pPrivate->pGladeXML) {
-    g_error("Can't find Glade file: %s. Dasher is unlikely to be correctly installed.", szGladeFilename);
+  if (szPrefGladeFilename) {
+    pPrivate->pPrefXML = dasher_main_open_glade_xml(szPrefGladeFilename);
+  }
+  else {
+    // If no separate preference file, preferences widget is in main glade xml
+    pPrivate->pPrefXML = (GladeXML *) g_object_ref(pPrivate->pGladeXML);
   }
-
-  glade_xml_signal_autoconnect(pPrivate->pGladeXML);
 
   // Save the details of some of the widgets for later
   //  pPrivate->pActionPane = glade_xml_get_widget(pPrivate->pGladeXML, "vbox39");
@@ -591,7 +622,7 @@ dasher_main_load_interface(DasherMain *pSelf) {
 static void 
 dasher_main_create_preferences(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
-  pPrivate->pPreferencesDialogue = dasher_preferences_dialogue_new(pPrivate->pGladeXML, pPrivate->pEditor, pPrivate->pAppSettings, GTK_WINDOW(pPrivate->pMainWindow));
+  pPrivate->pPreferencesDialogue = dasher_preferences_dialogue_new(pPrivate->pPrefXML, pPrivate->pEditor, pPrivate->pAppSettings, GTK_WINDOW(pPrivate->pMainWindow));
 }
 
 // DasherEditor *
@@ -722,7 +753,9 @@ dasher_main_save_state(DasherMain *pSelf) {
    iEditHeight = gtk_paned_get_position(GTK_PANED(pPrivate->pDivider));
 
    if(dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) != APP_STYLE_COMPOSE) {
-     dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_EDIT_HEIGHT, iEditHeight);
+     // APP_STYLE_DIRECT doesn't have an edit window.
+     if (dasher_app_settings_get_long(pPrivate->pAppSettings, APP_LP_STYLE) != APP_STYLE_DIRECT)
+       dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_EDIT_HEIGHT, iEditHeight);
      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_SCREEN_WIDTH, iWindowWidth);
      dasher_app_settings_set_long(pPrivate->pAppSettings, APP_LP_SCREEN_HEIGHT, iWindowHeight);
    }
@@ -949,17 +982,25 @@ dasher_main_setup_internal_layout(DasherMain *pSelf) {
 
 // TODO: Fold into setup controls?
 static void 
-dasher_main_set_filename(DasherMain *pSelf) {
+dasher_main_set_window_title(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
   const gchar *szFilename = dasher_editor_get_filename(pPrivate->pEditor);
 
+  // Note to translators: This is the name of the dasher program as it appears
+  // in a window title without a file.
+  gchar * dasher = _("Dasher");
   if(szFilename == 0) {
-    gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), "Dasher");
+    gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), dasher);
   }
   else {
-    // TODO: Prepend 'Dasher - ' to filename?
-    gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), szFilename);
+    // Note to translators: This is a format string for the name of the dasher
+    // program as it appears in a window, %s will be the filename.
+    gchar * titleFormat = _("Dasher - %s");
+    int len = strlen(szFilename);
+    gchar title[len+strlen(titleFormat)];
+    snprintf(title, sizeof(title), titleFormat, szFilename);
+    gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), title);
   }
 }
 
@@ -1369,7 +1410,7 @@ alphabet_combo_changed(GtkWidget *pWidget, gpointer pUserData) {
 extern "C" void 
 dasher_main_cb_filename_changed(DasherEditor *pEditor, gpointer pUserData) {
   if(g_pDasherMain)
-    dasher_main_set_filename(g_pDasherMain);
+    dasher_main_set_window_title(g_pDasherMain);
 }
 
 extern "C" void 
